<?php
/**
 * Daily Insight Pro core file.
 *
 * This is the template that includes all the other files for core featured of Daily Insight Pro
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */

/**
 * Load theme updater functions.
 * Action is used so that child themes can easily disable.
 */

function daily_insight_pro_theme_updater() {
  if( is_admin() ) {
    require get_template_directory() . '/updater/theme-updater.php';
  }
}
add_action( 'after_setup_theme', 'daily_insight_pro_theme_updater' );

/**
 * Include options function.
 */
require get_template_directory() . '/inc/options.php';


// Load customizer defaults values
require get_template_directory() . '/inc/customizer/defaults.php';


/**
 * Merge values from default options array and values from customizer
 *
 * @return array Values returned from customizer
 * @since Daily Insight Pro 1.0
 */
function daily_insight_pro_get_theme_options() {
  $daily_insight_pro_default_options = daily_insight_pro_get_default_theme_options();

  return array_merge( $daily_insight_pro_default_options , get_theme_mod( 'daily_insight_pro_theme_options', $daily_insight_pro_default_options ) ) ;
}


/**
  * Write message for featured image upload
  *
  * @return array Values returned from customizer
  * @since Daily Insight Pro 1.0
*/
function daily_insight_pro_slider_image_instruction( $content, $post_id ) {
  $allowed = array( 'page' );
  if ( in_array( get_post_type( $post_id ), $allowed ) ) {
    return $content .= '<p><b>' . esc_html__( 'Note', 'daily-insight-pro' ) . ':</b>' . esc_html__( ' The recommended size for image is 1350px by 760 while using it for slider', 'daily-insight-pro' ) . '</p>';
  } elseif ( 'jetpack-testimonial' == get_post_type( $post_id ) ) {
    return $content .= '<p><b>' . esc_html__( 'Note', 'daily-insight-pro' ) . ':</b>' . esc_html__( ' The recommended size for image is 340px by 340px while using it for testimonial', 'daily-insight-pro' ) . '</p>';
  }
   return $content;
}
add_filter( 'admin_post_thumbnail_html', 'daily_insight_pro_slider_image_instruction', 10, 2);

/**
 * Add helper functions.
 */
require get_template_directory() . '/inc/helpers.php';

/**
 * Add structural hooks.
 */
require get_template_directory() . '/inc/structure.php';

/**
 * Add metabox
 */
require get_template_directory() . '/inc/metabox.php';

/**
 * Sections additions.
 */
require get_template_directory() . '/inc/sections/sections.php';

/**
 * Custom widget additions.
 */
require get_template_directory() . '/inc/widgets/widgets.php';

/**
* TGM plugin additions.
*/
require get_template_directory() . '/inc/tgm-plugin/tgm-hook.php';

/**
* WooCommerce Compability additions.
*/
require get_template_directory() . '/inc/woocommerce.php';

