<?php
/**
 * Category Block Seven Customizer options
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */


// Add Category Block Seven enable section
$wp_customize->add_section( 'daily_insight_pro_category_block_seven_section', array(
	'title'             => esc_html__( 'Category Block Seven','daily-insight-pro' ),
	'description'       => esc_html__( 'Category Block Seven section options.', 'daily-insight-pro' ),
	'priority'			=> '10',
	'panel'             => 'daily_insight_pro_sections_panel'
) );

// Add Category Block Seven enable setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[enable_category_block_seven]', array(
	'default'           => $options['enable_category_block_seven'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[enable_category_block_seven]', array(
	'label'             => esc_html__( 'Check To Enable', 'daily-insight-pro' ),
	'section'           => 'daily_insight_pro_category_block_seven_section',
	'type'              => 'checkbox',
) );

// Add Category Block Seven content type setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_seven_type]', array(
	'default'           => $options['category_block_seven_type'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_select'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[category_block_seven_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_seven_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'daily_insight_pro_is_category_block_seven_active',
	'choices'         	=> array(
		'demo'			=> esc_html__( 'Demo','daily-insight-pro'),
		'category'		=> esc_html__( 'Category', 'daily-insight-pro' ),
		'popular'		=> esc_html__( 'Popular', 'daily-insight-pro' ),	
	)
) );

// Add Category Blcok Seven title setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_seven_title]', array(
	'default'           => $options['category_block_seven_title'],
	'transport'         => 'postMessage',
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[category_block_seven_title]', array(
	'label'             => esc_html__( 'Category Blcok Seven Title', 'daily-insight-pro' ),
	'section'           => 'daily_insight_pro_category_block_seven_section',
	'active_callback' 	=> 'daily_insight_pro_is_category_block_seven_demo_type_not_active',
	'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'daily_insight_pro_theme_options[category_block_seven_title]', array(
		'selector'            => '#trending-news-slider h2.entry-title',
		'render_callback'     => 'daily_insight_pro_customize_partial_category_block_seven_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add Category Block Two Section One number of posts setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_seven_no_of_posts]', array(
	'default'           => $options['category_block_seven_no_of_posts'],
	'validate_callback' => 'daily_insight_pro_validate_no_of_category_block_seven',
	'sanitize_callback' => 'daily_insight_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[category_block_seven_no_of_posts]', array(
	'label'           	=> esc_html__( 'Number Of Posts', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_seven_section',
	'type'            	=> 'number',
	'active_callback' 	=> 'daily_insight_pro_is_category_block_seven_content_as_category',
	'input_attrs'		=> array(
		'min'			=> '5',
		'max'			=> '10',
		'step'			=> '1',
		'style'			=> 'width:50px',
		),
) );

// Add Category Block Seven category drop-down setting and control
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_seven_category_type]', array(
	'default'			=> $options['category_block_seven_category_type'],			
	'sanitize_callback'	=> 'absint',
) );

$wp_customize->add_control( new Daily_Insight_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'daily_insight_pro_theme_options[category_block_seven_category_type]', array(
	'active_callback' 	=> 'daily_insight_pro_is_category_block_seven_content_as_category',
	'label'           	=> esc_html__( 'Select Category', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_seven_section',
	'type'            	=> 'dropdown-taxonomies',
 ) ) );