<?php
/**
 * Category Block Six Customizer options
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */


// Add Category Block Six enable section
$wp_customize->add_section( 'daily_insight_pro_category_block_six_section', array(
	'title'             => esc_html__( 'Category Block Six','daily-insight-pro' ),
	'description'       => esc_html__( 'Category Block Six section options.', 'daily-insight-pro' ),
	'priority'			=> '10',
	'panel'             => 'daily_insight_pro_sections_panel'
) );

// Add Category Block Six enable setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[enable_category_block_six]', array(
	'default'           => $options['enable_category_block_six'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[enable_category_block_six]', array(
	'label'             => esc_html__( 'Check To Enable', 'daily-insight-pro' ),
	'section'           => 'daily_insight_pro_category_block_six_section',
	'type'              => 'checkbox',
) );

// Add Category Block Six content type setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_six_type]', array(
	'default'           => $options['category_block_six_type'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_select'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[category_block_six_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_six_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'daily_insight_pro_is_category_block_six_active',
	'choices'         	=> array(
		'demo'			=> esc_html__( 'Demo','daily-insight-pro'),
		'category'		=> esc_html__( 'Category', 'daily-insight-pro' ),
	)
) );

// Add Category Block Six title setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_six_title]', array(
	'default'           => $options['category_block_six_title'],
	'transport'         => 'postMessage',
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[category_block_six_title]', array(
	'label'             => esc_html__( 'Category Block Six Title', 'daily-insight-pro' ),
	'section'           => 'daily_insight_pro_category_block_six_section',
	'active_callback' 	=> 'daily_insight_pro_is_category_block_six_content_as_category',
	'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'daily_insight_pro_theme_options[category_block_six_title]', array(
		'selector'            => '#latest-blog h2.entry-title',
		'render_callback'     => 'daily_insight_pro_customize_partial_category_block_six_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add Category Block Six category drop-down setting and control
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_six_category_type]', array(
	'default'			=> $options['category_block_six_category_type'],			
	'sanitize_callback'	=> 'daily_insight_pro_sanitize_category_list',
) );

$wp_customize->add_control( new Daily_Insight_Pro_Dropdown_Category_Control( $wp_customize, 'daily_insight_pro_theme_options[category_block_six_category_type]', array(
	'active_callback' 	=> 'daily_insight_pro_is_category_block_six_content_as_category',
	'label'           	=> esc_html__( 'Select Category', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_six_section',
	'type'            	=> 'dropdown-category',
 ) ) );