<?php
/**
 * Category Block Two Section One Customizer options
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */


// Add Category Block Two Section One enable section
$wp_customize->add_section( 'daily_insight_pro_category_block_two', array(
	'title'             => esc_html__( 'Category Block Two ','daily-insight-pro' ),
	'description'       => esc_html__( 'Category Block Two section options.', 'daily-insight-pro' ),
	'priority'			=> '10',
	'panel'             => 'daily_insight_pro_sections_panel'
) );

// Add Category Block Two Section One enable setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[enable_category_block_two]', array(
	'default'           => $options['enable_category_block_two'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[enable_category_block_two]', array(
	'label'             => esc_html__( 'Check To Enable', 'daily-insight-pro' ),
	'section'           => 'daily_insight_pro_category_block_two',
	'type'              => 'checkbox',
) );

// Add Category Block Two Section One content type setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_type]', array(
	'default'           => $options['category_block_two_type'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_select'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[category_block_two_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_two',
	'type'            	=> 'select',
	'active_callback' 	=> 'daily_insight_pro_is_category_block_two_active',
	'choices'         	=> array(
		'demo'			=> esc_html__( 'Demo','daily-insight-pro'),
		'category'		=> esc_html__( 'Category', 'daily-insight-pro' ),	
	)
) );

// hr setting and control 
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_one_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Daily_Insight_Pro_Customize_Horizontal_Line( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_one_hr]',
	array(
		'section'         => 'daily_insight_pro_category_block_two',
		'type'			  => 'hr',
		'active_callback' => 'daily_insight_pro_is_category_block_two_content_as_category'
) ) );

// Note control setting and control 
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_one_description]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Daily_Insight_Pro_Note_Control( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_one_description]',
	array(
		'section'         => 'daily_insight_pro_category_block_two',
		'label'			  => 'Category Block Two Section One',
		'type'			  => 'description',
		'active_callback' => 'daily_insight_pro_is_category_block_two_content_as_category'
) ) );

// Add Category Block Two Section One number of posts setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_one_no_of_posts]', array(
	'default'           => $options['category_block_two_section_one_no_of_posts'],
	'validate_callback' => 'daily_insight_pro_validate_no_of_category_block_two_section_one',
	'sanitize_callback' => 'daily_insight_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[category_block_two_section_one_no_of_posts]', array(
	'label'           	=> esc_html__( 'Section One Number Of Posts', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_two',
	'type'            	=> 'number',
	'active_callback' 	=> 'daily_insight_pro_is_category_block_two_content_as_category',
	'input_attrs'		=> array(
		'min'			=> '2',
		'max'			=> '8',
		'step'			=> '1',
		'style'			=> 'width:50px',
		),
) );

// Add Category Block Two Section One icon setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_one_icon]', array(
	'default'           => $options['category_block_two_section_one_icon'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[category_block_two_section_one_icon]', array(
	'label'                 =>  esc_html__( 'Section One Icon', 'daily-insight-pro' ),
    'section'               => 'daily_insight_pro_category_block_two',
    'type'                  => 'text',
    'active_callback' 	=> 'daily_insight_pro_is_category_block_two_content_as_category',
    'description'           => sprintf( esc_html__( 'Use font awesome icon: Eg: %1$s. %2$sSee more here%3$s', 'daily-insight-pro' ), 'fa-laptop','<a href="'.esc_url('http://fontawesome.io/icons/').'" target="_blank">','</a>' )
) );

// Add Category Block Two Section One category drop-down setting and control
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_one_category_type]', array(
	'default'			=> $options['category_block_two_section_one_category_type'],			
	'sanitize_callback'	=> 'absint',
) );

$wp_customize->add_control( new Daily_Insight_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_one_category_type]', array(
	'active_callback' 	=> 'daily_insight_pro_is_category_block_two_content_as_category',
	'label'           	=> esc_html__( 'Select Category', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_two',
	'type'            	=> 'dropdown-taxonomies',
 ) ) );

// hr setting and control 
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_two_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Daily_Insight_Pro_Customize_Horizontal_Line( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_two_hr]',
	array(
		'section'         => 'daily_insight_pro_category_block_two',
		'type'			  => 'hr',
		'active_callback' => 'daily_insight_pro_is_category_block_two_content_as_category'
) ) );

// Note control setting and control 
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_two_description]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Daily_Insight_Pro_Note_Control( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_two_description]',
	array(
		'section'         => 'daily_insight_pro_category_block_two',
		'label'			  => 'Category Block Two Section Two',
		'type'			  => 'description',
		'active_callback' => 'daily_insight_pro_is_category_block_two_content_as_category'
) ) );

// Add Category Block Two Section Two icon setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_two_icon]', array(
	'default'           => $options['category_block_two_section_two_icon'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[category_block_two_section_two_icon]', array(
	'label'                 =>  esc_html__( 'Section Two Icon', 'daily-insight-pro' ),
    'section'               => 'daily_insight_pro_category_block_two',
    'type'                  => 'text',
    'active_callback' 	=> 'daily_insight_pro_is_category_block_two_content_as_category',
    'description'           => sprintf( esc_html__( 'Use font awesome icon: Eg: %1$s. %2$sSee more here%3$s', 'daily-insight-pro' ), 'fa-heart','<a href="'.esc_url('http://fontawesome.io/icons/').'" target="_blank">','</a>' )
) );

// Add Category Block Two Section Two category drop-down setting and control
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_two_category_type]', array(
	'default'			=> $options['category_block_two_section_two_category_type'],			
	'sanitize_callback'	=> 'absint',
) );

$wp_customize->add_control( new Daily_Insight_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_two_category_type]', array(
	'active_callback' 	=> 'daily_insight_pro_is_category_block_two_content_as_category',
	'label'           	=> esc_html__( 'Select Category', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_two',
	'type'            	=> 'dropdown-taxonomies',
 ) ) );


// hr setting and control 
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_three_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Daily_Insight_Pro_Customize_Horizontal_Line( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_three_hr]',
	array(
		'section'         => 'daily_insight_pro_category_block_two',
		'type'			  => 'hr',
		'active_callback' => 'daily_insight_pro_is_category_block_two_content_as_category'
) ) );

// Note control setting and control 
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_three_description]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Daily_Insight_Pro_Note_Control( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_three_description]',
	array(
		'section'         => 'daily_insight_pro_category_block_two',
		'label'			  => 'Category Block Two Section Three',
		'type'			  => 'description',
		'active_callback' => 'daily_insight_pro_is_category_block_two_content_as_category'
) ) );

// Add Category Block Two Section Three icon setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_three_icon]', array(
	'default'           => $options['category_block_two_section_three_icon'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[category_block_two_section_three_icon]', array(
	'label'                 =>  esc_html__( 'Section Three Icon', 'daily-insight-pro' ),
    'section'               => 'daily_insight_pro_category_block_two',
    'type'                  => 'text',
    'active_callback' 	=> 'daily_insight_pro_is_category_block_two_content_as_category',
    'description'           => sprintf( esc_html__( 'Use font awesome icon: Eg: %1$s. %2$sSee more here%3$s', 'daily-insight-pro' ), 'fa-globe','<a href="'.esc_url('http://fontawesome.io/icons/').'" target="_blank">','</a>' )
) );

// Add Category Block Two Section Three category drop-down setting and control
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_three_category_type]', array(
	'default'			=> $options['category_block_two_section_three_category_type'],			
	'sanitize_callback'	=> 'absint',
) );

$wp_customize->add_control( new Daily_Insight_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_three_category_type]', array(
	'active_callback' 	=> 'daily_insight_pro_is_category_block_two_content_as_category',
	'label'           	=> esc_html__( 'Select Category', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_two',
	'type'            	=> 'dropdown-taxonomies',
 ) ) );

// hr setting and control 
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_four_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Daily_Insight_Pro_Customize_Horizontal_Line( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_four_hr]',
	array(
		'section'         => 'daily_insight_pro_category_block_two',
		'type'			  => 'hr',
		'active_callback' => 'daily_insight_pro_is_category_block_two_content_as_category'
) ) );

// Note control setting and control 
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_four_description]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Daily_Insight_Pro_Note_Control( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_four_description]',
	array(
		'section'         => 'daily_insight_pro_category_block_two',
		'label'			  => 'Category Block Two Section Four',
		'type'			  => 'description',
		'active_callback' => 'daily_insight_pro_is_category_block_two_content_as_category'
) ) );

// Add Category Block Two Section Four icon setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_four_icon]', array(
	'default'           => $options['category_block_two_section_four_icon'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[category_block_two_section_four_icon]', array(
	'label'                 =>  esc_html__( 'Section Four Icon', 'daily-insight-pro' ),
    'section'               => 'daily_insight_pro_category_block_two',
    'type'                  => 'text',
    'active_callback' 	=> 'daily_insight_pro_is_category_block_two_content_as_category',
    'description'           => sprintf( esc_html__( 'Use font awesome icon: Eg: %1$s. %2$sSee more here%3$s', 'daily-insight-pro' ), 'fa-hourglass','<a href="'.esc_url('http://fontawesome.io/icons/').'" target="_blank">','</a>' )
) );

// Add Category Block Two Section Four category drop-down setting and control
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_four_category_type]', array(
	'default'			=> $options['category_block_two_section_four_category_type'],			
	'sanitize_callback'	=> 'absint',
) );

$wp_customize->add_control( new Daily_Insight_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_four_category_type]', array(
	'active_callback' 	=> 'daily_insight_pro_is_category_block_two_content_as_category',
	'label'           	=> esc_html__( 'Select Category', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_two',
	'type'            	=> 'dropdown-taxonomies',
 ) ) );


// hr setting and control 
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_five_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Daily_Insight_Pro_Customize_Horizontal_Line( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_five_hr]',
	array(
		'section'         => 'daily_insight_pro_category_block_two',
		'type'			  => 'hr',
		'active_callback' => 'daily_insight_pro_is_category_block_two_content_as_category'
) ) );

// Note control setting and control 
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_five_description]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Daily_Insight_Pro_Note_Control( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_five_description]',
	array(
		'section'         => 'daily_insight_pro_category_block_two',
		'label'			  => 'Category Block Two Section Five',
		'type'			  => 'description',
		'active_callback' => 'daily_insight_pro_is_category_block_two_content_as_category'
) ) );

// Add Category Block Two Section Five icon setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_five_icon]', array(
	'default'           => $options['category_block_two_section_five_icon'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[category_block_two_section_five_icon]', array(
	'label'                 =>  esc_html__( 'Section Five Icon', 'daily-insight-pro' ),
    'section'               => 'daily_insight_pro_category_block_two',
    'type'                  => 'text',
    'active_callback' 	=> 'daily_insight_pro_is_category_block_two_content_as_category',
    'description'           => sprintf( esc_html__( 'Use font awesome icon: Eg: %1$s. %2$sSee more here%3$s', 'daily-insight-pro' ), 'fa-building-o','<a href="'.esc_url('http://fontawesome.io/icons/').'" target="_blank">','</a>' )
) );

// Add Category Block Two Section Five category drop-down setting and control
$wp_customize->add_setting( 'daily_insight_pro_theme_options[category_block_two_section_five_category_type]', array(
	'default'			=> $options['category_block_two_section_five_category_type'],			
	'sanitize_callback'	=> 'absint',
) );

$wp_customize->add_control( new Daily_Insight_Pro_Dropdown_Taxonomies_Control( $wp_customize, 'daily_insight_pro_theme_options[category_block_two_section_five_category_type]', array(
	'active_callback' 	=> 'daily_insight_pro_is_category_block_two_content_as_category',
	'label'           	=> esc_html__( 'Select Category', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_category_block_two',
	'type'            	=> 'dropdown-taxonomies',
 ) ) );

