<?php
/**
 * Jetpack Compatibility File.
 *
 * @link https://jetpack.com/
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */

/**
 * Jetpack setup function.
 *
 * See: https://jetpack.com/support/infinite-scroll/
 * See: https://jetpack.com/support/responsive-videos/
 */
function daily_insight_pro_jetpack_setup() {

	$options = daily_insight_pro_get_theme_options();

	$pagination_type	= isset( $options['pagination_type'] ) ? $options['pagination_type'] : '';
	$type = '';

	if ( in_array( $pagination_type, array( 'infinite-click', 'infinite-scroll' ) ) ) {
		if ( 'infinite-click' == $pagination_type ) {
			$type = 'click';
		} elseif( 'infinite-scroll' == $pagination_type ){
			$type = 'scroll';
		}

		// Add theme support for Infinite Scroll.
		add_theme_support( 'infinite-scroll', array(
			'type'		=> $type,
			'container' => 'main',
			'render'    => 'daily_insight_pro_infinite_scroll_render',
			'footer'    => false,
		) );
	}

	// Add theme support for Responsive Videos.
	add_theme_support( 'jetpack-responsive-videos' );
}
add_action( 'after_setup_theme', 'daily_insight_pro_jetpack_setup' );

/**
 * Custom render function for Infinite Scroll.
 */
function daily_insight_pro_infinite_scroll_render() {
	while ( have_posts() ) {
		the_post();
		if ( is_search() ) :
			get_template_part( 'template-parts/content', 'search' );
		else :
			get_template_part( 'template-parts/content', get_post_format() );
		endif;
	}
}

/**
 * Remove Infinite Scroll.
 */
function daily_insight_pro_disable_jetpack_infinite_scroll_conditionally() {
    if ( function_exists( 'is_woocommerce' ) && true === is_woocommerce() ) {
        remove_theme_support( 'infinite-scroll' );
    }
}
add_action( 'template_redirect', 'daily_insight_pro_disable_jetpack_infinite_scroll_conditionally', 9 );