<?php
/**
 * Daily Insight Pro options
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */

/**
 * Returns list of typography
 * @return array font styles
 */
function daily_insight_pro_typography_options(){

    $choices = array(
      'default'         => esc_html__( 'Default', 'daily-insight-pro' ),
      'poppins'         => esc_html__( 'POPPINS AND COURGETTE FONT', 'daily-insight-pro' ),
      'roboto'          => esc_html__( 'ROBOTO AND MONTSERRAT FONT', 'daily-insight-pro' ),
      'raleway'         => esc_html__( 'RALEWAY AND POPPINS FONT', 'daily-insight-pro' ),
      'courgette'       => esc_html__( 'COURGETTE AND ROBOTO FONT', 'daily-insight-pro' ),
      'montserrat'      => esc_html__( 'MONTSERRAT FONT', 'daily-insight-pro' ),
    );
    $output = apply_filters( 'daily_insight_pro_typography_options', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

}

/**
 * Site Layout
 * @return array site layout options
 */
function daily_insight_pro_site_layout() {
  $daily_insight_pro_site_layout = array(
    'wide'  => esc_html__( 'Wide', 'daily-insight-pro' ),
    'boxed' => esc_html__( 'Boxed', 'daily-insight-pro' ),
  );

  $output = apply_filters( 'daily_insight_pro_site_layout', $daily_insight_pro_site_layout );

  return $output;
}

/**
 * Sidebar position
 * @return array Sidbar positions
 */
function daily_insight_pro_sidebar_position() {
  $daily_insight_pro_sidebar_position = array(
    'right-sidebar' => esc_html__( 'Right', 'daily-insight-pro' ),
    'left-sidebar'  => esc_html__( 'Left', 'daily-insight-pro' ),
    'no-sidebar'    => esc_html__( 'No Sidebar', 'daily-insight-pro' ),
  );

  $output = apply_filters( 'daily_insight_pro_sidebar_position', $daily_insight_pro_sidebar_position );

  return $output;
}

/**
 * Pagination
 * @return array site pagination options
 */
function daily_insight_pro_pagination_options() {
  $daily_insight_pro_pagination_options = array(
    'numeric'         => esc_html__( 'Numeric', 'daily-insight-pro' ),
    'default'         => esc_html__( 'Default(Older/Newer)', 'daily-insight-pro' ),
    'infinite-scroll' => esc_html__( 'Infinite-Scroll', 'daily-insight-pro' ),
    'infinite-click'  => esc_html__( 'Infinite-Click', 'daily-insight-pro' ),
  );

  $output = apply_filters( 'daily_insight_pro_pagination_options', $daily_insight_pro_pagination_options );

  return $output;
}


/**
 * Slider effects
 * @return array Slider effects
 */
function daily_insight_pro_slider_effect() {
  $daily_insight_pro_slider_effect = array(
    'cubic-bezier(0.680, 0, 0.265, 1)'            => esc_html__( 'Default', 'daily-insight-pro' ),
    'fade'                                        => esc_html__( 'Fade', 'daily-insight-pro' ),
    'cubic-bezier(0.250, 0.250, 0.750, 0.750)'    => esc_html__( 'Linear', 'daily-insight-pro' ),
    'cubic-bezier(0.250, 0.100, 0.250, 1.000)'    => esc_html__( 'Ease', 'daily-insight-pro' ),
    'cubic-bezier(0.950, 0.050, 0.795, 0.035)'    => esc_html__( 'cubic', 'daily-insight-pro' ),
    'cubic-bezier(0.600, -0.280, 0.735, 0.045)'   => esc_html__( 'Ease In Back', 'daily-insight-pro' ),
    'cubic-bezier(0.785, 0.135, 0.150, 0.860)'    => esc_html__( 'EaseInOutCirc', 'daily-insight-pro' ),
    'cubic-bezier(0.680, -0.550, 0.265, 1.550)'   => esc_html__( 'EaseInOutBack', 'daily-insight-pro' ),
  );

  $output =  apply_filters( 'daily_insight_pro_slider_effect', $daily_insight_pro_slider_effect );

  // Sort array in ascending order, according to the key:
  if ( ! empty( $output ) ) {
    ksort( $output );
  }

  return $output;
}


/**
 * Slider
 * @return array slider options
 */
function daily_insight_pro_enable_disable_options() {
  $daily_insight_pro_enable_disable_options = array(
    'static-frontpage'  => esc_html__( 'Static Frontpage', 'daily-insight-pro' ),
    'disabled'          => esc_html__( 'Disabled', 'daily-insight-pro' ),
  );

  $output = apply_filters( 'daily_insight_pro_enable_disable_options', $daily_insight_pro_enable_disable_options );

  return $output;
}


/**
 * Selected sidebar
 * @return array available Sidbar
 */
function daily_insight_pro_selected_sidebar() {
  $daily_insight_pro_selected_sidebar = array(
    'sidebar-1'          => esc_html__( 'Default ( Primary Sidebar )', 'daily-insight-pro' ),
    'optional_sidebar_1' => esc_html__( 'Optional Sidebar 1', 'daily-insight-pro' ),
    'optional_sidebar_2' => esc_html__( 'Optional Sidebar 2', 'daily-insight-pro' ),
    'optional_sidebar_3' => esc_html__( 'Optional Sidebar 3', 'daily-insight-pro' ),
  );

  $output = apply_filters( 'daily_insight_pro_selected_sidebar', $daily_insight_pro_selected_sidebar );

  return $output;
}