<?php

/**
 * Category Block Four section
 *
 * This is the template for the content of Category Block Four section.
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */

if ( ! function_exists( 'daily_insight_pro_add_category_block_four' ) ) :
    /**
     * Add Category Block Four section
     *
     * @since Daily Insight Pro 1.0
     */
    function daily_insight_pro_add_category_block_four() { 

        // Check if Category Block Four is enabled on frontpage
        $options = daily_insight_pro_get_theme_options(); 

        $category_block_four_enable = (bool)( $options['enable_category_block_four'] );
        if ( true !== $category_block_four_enable ) {
            return false;
        }
        // Get Category Block Four section details
        $section_details = array();
        $section_details = apply_filters( 'daily_insight_pro_filter_category_block_four_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render Category Block Four section .
        daily_insight_pro_render_category_block_four_section( $section_details );
    }
endif;
add_action( 'daily_insight_pro_front_page_container_action', 'daily_insight_pro_add_category_block_four', 40 );


if ( ! function_exists( 'daily_insight_pro_get_category_block_four_section_details' ) ) :
    /**
     * Category Block Four section details.
     *
     * @since Daily Insight Pro 1.0
     *
     * @param array $input Category Block Four section details.
     */
    function daily_insight_pro_get_category_block_four_section_details( $input ) {
        $options = daily_insight_pro_get_theme_options(); 

        // Category Block Four type
        $category_block_four_content_type    = $options['category_block_four_type'];
        $no_of_posts = $options['category_block_four_no_of_posts'];
        $content = array();

        switch ( $category_block_four_content_type ) {

            case 'demo':
                $no_of_posts = 7; // Initialize and overwrite no of posts in demo by 3
                $images = array( 'featured-gallery-01.jpg', 'featured-gallery-02.jpg', 'featured-gallery-03.jpg','featured-gallery-01.jpg','featured-gallery-02.jpg', 'featured-gallery-03.jpg', 'featured-gallery-01.jpg' ); // An array of demo images

                for ( $index = 0; $index < $no_of_posts ; $index++ ) {
                    $content[$index]['img_array']= array( get_template_directory_uri(). '/assets/uploads/'. $images[$index] );
                    $content[$index]['url']      = '#';
                    $content[$index]['title']    = esc_html__( 'Proin gravida nibh vel velit  auctor aliquet. Aenean sollicit.','daily-insight-pro' );
                }
            break;

            case 'category':
              
                $category = !empty( $options['category_block_four_category_type'] ) ? absint( $options['category_block_four_category_type'] ) : '';

                if ( ! empty( $category ) ) {

                    $args = array(
                        'cat'                 => $category,
                        'posts_per_page'      => $no_of_posts,
                    );
                }
                if( !empty( $args ) ) :

                    $custom_posts = get_posts( $args );

                    $index = 0;
                    foreach ( $custom_posts as $key => $custom_post ) {

                        if ( has_post_thumbnail( $custom_post->ID ) ) {
                            $img_array            = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'daily-insight-pro-travel-long' );
                        } else {
                            $img_array = array ( get_template_directory_uri() . '/assets/uploads/no-featured-image-780x390.jpg' );
                        }

                        if ( isset( $img_array ) ) {
                            $content[$index]['img_array'] = $img_array;
                        }

                        $content[$index]['title']    = get_the_title( $custom_post->ID );
                        $content[$index]['url']      = get_the_permalink( $custom_post->ID );
                        $index++;
                    }
                endif;
            break;

            default:
            break;
        }
        if ( ! empty( $content ) ) {
            $input = $content;
        }
    return $input; 
    }
endif;
// Category Block Four section content details.
add_filter( 'daily_insight_pro_filter_category_block_four_section_details', 'daily_insight_pro_get_category_block_four_section_details' );

if ( ! function_exists( 'daily_insight_pro_render_category_block_four_section' ) ) :
    /**
     * Start section Category Block Four
     *
     * @return string Category Block Four content
     * @since Daily Insight Pro 1.0
     *      
     */
    function daily_insight_pro_render_category_block_four_section( $content_details = array() ) {

        $options         = daily_insight_pro_get_theme_options();
        $section_title   = get_cat_name( $options['category_block_four_category_type'] );
        $slider_control  = ( $options['enable_slider_controls_category_block_four'] == true ) ? 'true' : 'false';
        $slider_dragable = ( $options['enable_slider_dragable_category_block_four'] == true ) ? 'true' : 'false';
        $slider_pause    = ( $options['slider_pause_on_hover_category_block_four'] == true ) ? 'true' : 'false';

        if( $options['category_block_four_type'] == 'demo' ) {
            $data_slick_value = '{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "arrows":true, "autoplay": true, "fade": false }';
        }
        else{
            $data_slick_value = '{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "autoplay": true, "pauseOnHover":'. esc_attr( $slider_pause ).', "arrows":'.esc_attr( $slider_control ).',"draggable":'.esc_attr( $slider_dragable ).',"fade": false }';
        }

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <section id="featured-gallery-slider" class="page-section">
            <?php 
            $section_title = ( $options['category_block_four_type'] == 'demo' ) ? esc_html__( 'Business','daily-insight-pro' ) : $section_title;
            if( !empty( $section_title ) ) : ?>
            <header class="entry-header">
                <h2 class="entry-title category-title"><?php echo esc_html( $section_title ); ?></h2>  
            </header>
            <?php endif; ?>

            <div class="entry-content regular" data-effect="cubic-bezier(0.680, 0, 0.265, 1)" data-slick='<?php echo $data_slick_value; ?>'>

            <?php foreach ( $content_details as $content ) { ?>
                
                <div class="slider-item" data-thumb="<?php echo esc_url( $content['img_array'][0] ); ?>">
                  <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                  <div class="slider-title">
                    <h6><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h6>
                  </div>
                </div><!-- .slider-item -->
            <?php } ?>
              </div><!-- .entry-content-->
            </section><!-- #featured-gallery-slider -->
    <?php }
endif;