<?php

/**
 * Latest Post section
 *
 * This is the template for the content of Latest Post section.
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */

if ( ! function_exists( 'daily_insight_pro_add_latest_post_section' ) ) :
    /**
     * Add Latest Post section
     *
     * @since Daily Insight Pro 1.0
     */
    function daily_insight_pro_add_latest_post_section() {

        // Check if Latest Post is enabled on frontpage
        $options = daily_insight_pro_get_theme_options(); 

        $latest_post_enable = apply_filters( 'daily_insight_pro_section_status', true, 'enable_latest_post' );
        if ( true !== $latest_post_enable ) {
            return false;
        }
        // Get Latest Post section details
        $section_details = array();
        $section_details = apply_filters( 'daily_insight_pro_filter_latest_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render Latest Post section .
        daily_insight_pro_render_latest_post_section( $section_details );
    }
endif;
add_action( 'daily_insight_pro_content_start_action', 'daily_insight_pro_add_latest_post_section', 50 );


if ( ! function_exists( 'daily_insight_pro_get_latest_post_section_details' ) ) :
    /**
     * Latest Post section details.
     *
     * @since Daily Insight Pro 1.0
     *
     * @param array $input Latest Post section details.
     */
    function daily_insight_pro_get_latest_post_section_details( $input ) {
        $options = daily_insight_pro_get_theme_options(); 

        // Latest Post type
        $latest_post_content_type    = $options['latest_post_type'];

        $content = array();

        switch ( $latest_post_content_type ) {

            case 'demo':
                $no_of_posts = 3; // Initialize and overwrite no of posts in demo by 3
                $images = array( 'post-01.jpg', 'post-02.jpg', 'post-03.jpg' ); // An array of demo images
                $terms  = array( esc_html__( 'Design','daily-insight-pro' ), esc_html__( 'Technology','daily-insight-pro' ), esc_html__( 'Lifestyle','daily-insight-pro' ) ); // An array of demo category

                for ( $index = 0; $index < $no_of_posts ; $index++ ) {
                    $content[$index]['date']     = 'Aug,03 2016';
                    $content[$index]['img_array']= array( get_template_directory_uri(). '/assets/uploads/'. $images[$index] );
                    $content[$index]['url']      = '#';
                    $content[$index]['title']    = esc_html__( 'Proin gravida nibh vel velit  auctor aliquet. Aenean sollicit.','daily-insight-pro' );
                    $content[$index]['terms']    = $terms[$index];
                }
                        
                $input =  $content;
            break;

            case 'recent-post':

                $args = array(
                    'posts_per_page'      => 3,
                    'ignore_sticky_posts' => true,
                );

                $custom_posts = get_posts( $args );

                    $index = 0;
                    foreach ( $custom_posts as $key => $custom_post ) {

                        if ( has_post_thumbnail( $custom_post->ID ) ) {
                            $img_array            = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'daily-insight-pro-latest-post' );
                            $content[$index]['img_array'] = $img_array;
                        }
                        $year  = get_the_time('Y', $custom_post->ID );
                        $month = get_the_time('m', $custom_post->ID );
                        $day   = get_the_time('d', $custom_post->ID );

                        $content[$index]['date_link'] = get_day_link( $year, $month, $day );
                        $content[$index]['date']      = get_the_date( '' , $custom_post );
                        $content[$index]['title']     = get_the_title( $custom_post->ID );
                        $content[$index]['url']       = get_the_permalink( $custom_post->ID );
                        $content[$index]['terms']     = get_the_category( $custom_post->ID ); 
                        $index++;
                    }
            break;

            default:
            break;
        }
        if ( ! empty( $content ) ) {
            $input = $content;
        }
    return $input; 
    }
endif;
// Latest Post section content details.
add_filter( 'daily_insight_pro_filter_latest_post_section_details', 'daily_insight_pro_get_latest_post_section_details' );

if ( ! function_exists( 'daily_insight_pro_render_latest_post_section' ) ) :
    /**
     * Start section Latest Post
     *
     * @return string Latest Post content
     * @since Daily Insight Pro 1.0
     *      
     */
    function daily_insight_pro_render_latest_post_section( $content_details = array() ) {

        $options = daily_insight_pro_get_theme_options();
        $content_type = $options['latest_post_type'];
        $blog_posts = get_option( 'page_for_posts' );
        $blog_posts_link = get_permalink( $blog_posts );

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <section id="latest-posts" class="page-section container bg-white three-columns">
            <?php 
            $section_title = ( $options['latest_post_type'] == 'demo' ) ? esc_html__( 'Latest Post','daily-insight-pro' ) : $options['latest_post_title'];
            $section_link = ( $options['latest_post_type'] == 'demo' ) ? esc_html__( '#','daily-insight-pro' ) : $blog_posts_link;
            if( ! empty ( $section_title ) ):?>
                <header class="entry-header">
                    <h2 class="entry-title"><?php echo esc_html( $section_title ); ?></h2>  
                    <a href="<?php echo esc_url( $section_link ); ?>" class="view-more"><?php esc_html_e( 'View more','daily-insight-pro' ); ?></a>
                </header><!-- .entry-header -->
            <?php endif; ?>

            <div class="entry-content">
                <div class="row">
                    <?php foreach( $content_details as $content ) : 
                    $post_categories = $content['terms']; ?>
                    <div class="column-wrapper">
                        
                        <?php if( !empty ( $content['img_array'] ) ) : ?>
                        <div class="image-wrapper">
                            <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                            <div class="overlay"></div></a>
                        </div><!-- .image-wrapper -->
                        <?php endif; ?>
                        
                        <?php if( !empty ( $content['title'] ) ) : ?>

                        <div class="post-wrapper">
                            <div class="post-title">
                                <h5><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h5>

                                <?php if( !empty ( $post_categories ) ) :
                                if( 'demo' == $content_type ) { ?>
                                    <a class="category" href="#"><?php echo esc_html( $post_categories ); ?></a>
                                    <a href="#"><time><?php echo esc_html( $content['date'] ); ?></time></a>
                                <?php }
                                else { 
                                    foreach ( $post_categories as $post_category ) {
                                        $category_id   = $post_category->term_id;
                                        $category_name = $post_category->name;
                                        $category_url  = get_category_link( $category_id );
                                        ?>
                                         <a class="category" href="<?php echo esc_url( $category_url ); ?>"><?php echo esc_html( $category_name ); ?></a> 
                                         <?php

                                        } ?>                                   
                                    <a href="<?php echo esc_url( $content['date_link'] ); ?>"><time><?php echo esc_html( $content['date'] ); ?></time></a>
                                <?php  }
                                endif; ?>
                            </div><!-- .post-title -->
                        </div><!-- .post-wrapper -->
                        <?php endif; ?>
                    </div><!-- .column-wrapper -->
                    <?php endforeach; ?>
                </div><!-- .row -->
            </div><!-- .entry-content -->
        </section><!-- #latest-posts -->
<?php
    }
endif;