<?php
/**
 * Custom video Widget
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro 
 * @since Daily Insight Pro 1.0
 */

if ( ! class_exists( 'Daily_Insight_Pro_video_widget' ) ) :
	/**
	 * Adds Tp video widget.
	 */
	class Daily_Insight_Pro_video_widget extends WP_Widget{

		/**
		 * Register widget with WordPress.
		 */
		function __construct() {
			parent::__construct(
				'tp-widget-video', // Base ID
				esc_html__( 'TP: Video Widget', 'daily-insight-pro' ), // Name
				array( 'classname' => 'widget_video', 'description' => esc_html__( 'An widget to upload video in sidebar.', 'daily-insight-pro' ), ) // Args
			);
		}


		/**
		 * Front-end display of widget.
		 *
		 * @see WP_Widget::widget()
		 *
		 * @param array $args     Widget arguments.
		 * @param array $instance Saved values from database.
		 */
		public function widget( $args, $instance ) {
			extract( $args , EXTR_SKIP );

			$title         = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
			$tpiw_link     = ! empty( $instance['tpiw_link'] ) ? $instance['tpiw_link'] : '';
			$tpiw_alt_text = ! empty( $instance['tpiw_alt_text'] ) ? $instance['tpiw_alt_text'] : '';

	        if ( ! empty ( $tpiw_link ) ) {

				$queryString = parse_url($tpiw_link, PHP_URL_QUERY);
				parse_str($queryString, $params);
	          	if (isset($params['v'])) {
				    $tpiw_image_url 		= "i3.ytimg.com/vi/{$params['v']}/maxresdefault.jpg";
				}
	        }
			echo $args['before_widget'];

			if( !empty( $title ) ){
				echo $before_title . esc_html( $title ) . $after_title;
			}

			if ( ! empty( $tpiw_image_url ) ) {
				$sizes    = array();
				$alt_text = ( ! empty( $tpiw_alt_text ) ) ? $tpiw_alt_text : basename( $tpiw_image_url );
				$imgtag   = '<img src="' . esc_url( $tpiw_image_url ) . '" alt="' . esc_attr( $alt_text ) . '"/>';

				echo '<div class="widget-wrap">
	              			<div class="video">  
	                			<a href="'. esc_url( $tpiw_link ) .'" data-gal="prettyPhoto">
	                  			<span class="btn-play"><i class="fa fa-play"></i></span>'. $imgtag .'</a>
	              			</div><!-- .video -->
            			</div>';
	        } // End if : video is there.
			        
			echo $args['after_widget'];
		}

		/**
		 * Back-end widget form.
		 *
		 * @see WP_Widget::form()
		 *
		 * @param array $instance Previously saved values from database.
		 */
		public function form( $instance ) {
			// Defaults.
	        $instance = wp_parse_args( (array) $instance, array(
				'title'         => '',
				'tpiw_link'     => '',
				'tpiw_alt_text' => '',
	      	) );

			$title         = htmlspecialchars( $instance['title'] );
			$tpiw_link     = isset( $instance['tpiw_link'] ) ? $instance['tpiw_link'] : '';
			$tpiw_alt_text = isset( $instance['tpiw_alt_text'] ) ? $instance['tpiw_alt_text'] : '';
			?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title (Optional):', 'daily-insight-pro' ); ?></label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
			</p>

			<p>
		      	<label for="<?php echo esc_attr( $this->get_field_id( 'tpiw_link' ) ); ?>"><?php esc_html_e( 'Video URL', 'daily-insight-pro' ); ?>:</label>
		        <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'tpiw_link' ) ); ?>"
		        name="<?php echo esc_attr( $this->get_field_name( 'tpiw_link' ) ); ?>" type="text" value="<?php echo esc_url( $tpiw_link ); ?>" />
		    </p>

		    <p>
		      	<label for="<?php echo esc_attr( $this->get_field_id( 'tpiw_alt_text' ) ); ?>"><?php esc_html_e( 'Alt Text', 'daily-insight-pro' ); ?>:</label>
		        <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'tpiw_alt_text' ) ); ?>"
		        name="<?php echo esc_attr( $this->get_field_name( 'tpiw_alt_text' ) ); ?>" type="text" value="<?php echo esc_attr( $tpiw_alt_text ); ?>" />
		    </p>
		<?php
		}

		/**
		 * Sanitize widget form values as they are saved.
		 *
		 * @see WP_Widget::update()
		 *
		 * @param array $new_instance Values just sent to be saved.
		 * @param array $old_instance Previously saved values from database.
		 *
		 * @return array Updated safe values to be saved.
		 */
		public function update( $new_instance, $old_instance ) {
			$instance                  = $old_instance;

			$instance['title']         = ( ! empty( $new_instance['title'] ) ) ? strip_tags( stripslashes ( $new_instance['title'] ) ) : '';
			$instance['tpiw_link']     = esc_url_raw( $new_instance['tpiw_link'] );
			$instance['tpiw_alt_text'] = sanitize_text_field( $new_instance['tpiw_alt_text'] );

			return $instance;
		}

	} // class tp_video_widget
endif;

function daily_insight_pro_register_video_widget() {
	register_widget( 'Daily_Insight_Pro_video_widget' );
}
add_action( 'widgets_init', 'daily_insight_pro_register_video_widget' );
